pub struct VecValue { /* private fields */ }Expand description
A fixed box of Values with bit compression. It is more efficient than Vec<Value>.
Implementations
Sourceimpl VecValue
impl VecValue
Sourcepub fn repeat(value: Value, len: usize) -> VecValue
pub fn repeat(value: Value, len: usize) -> VecValue
Create a new vector with the same value repeated for len times.
Sourcepub fn difference(&self, start: usize, vvalue: &VecValue) -> BitVec ⓘ
pub fn difference(&self, start: usize, vvalue: &VecValue) -> BitVec ⓘ
Get the bits that are different in the vector
Sourcepub fn iter(&self) -> VecValueIter<'_> ⓘ
pub fn iter(&self) -> VecValueIter<'_> ⓘ
Get immutable iterator into bit content.