pub struct Writer<W: Write> { /* private fields */ }Expand description
Struct wrapping an io::Write with methods for writing VCD commands and data.
Implementations
Sourceimpl<W: Write> Writer<W>
impl<W: Write> Writer<W>
Sourcepub fn new(writer: W) -> Writer<W>
pub fn new(writer: W) -> Writer<W>
Creates a Writer, wrapping an io::Write.
let mut buf = Vec::new();
let mut vcd = vcd_ng::Writer::new(&mut buf);Sourcepub fn header(&mut self, h: &Header) -> Result<()>
pub fn header(&mut self, h: &Header) -> Result<()>
Writes a complete header with the fields from a Header struct from the parser.
Sourcepub fn timescale(&mut self, ts: u32, unit: TimescaleUnit) -> Result<()>
pub fn timescale(&mut self, ts: u32, unit: TimescaleUnit) -> Result<()>
Writes a $timescale command.
Sourcepub fn add_module(&mut self, identifier: &str) -> Result<()>
pub fn add_module(&mut self, identifier: &str) -> Result<()>
Writes a $scope command for a module.
Convenience wrapper around scope_def.
Sourcepub fn scope(&mut self, s: &Scope) -> Result<()>
pub fn scope(&mut self, s: &Scope) -> Result<()>
Writes a $scope command, a series of $var commands, and an $upscope commands from
a Scope structure from the parser.
Sourcepub fn var_def(
&mut self,
var_type: VarType,
width: u32,
id: IdCode,
reference: &str,
index: Option<ReferenceIndex>,
) -> Result<()>
pub fn var_def( &mut self, var_type: VarType, width: u32, id: IdCode, reference: &str, index: Option<ReferenceIndex>, ) -> Result<()>
Writes a $var command with a specified id.
Sourcepub fn add_var(
&mut self,
var_type: VarType,
width: u32,
reference: &str,
index: Option<ReferenceIndex>,
) -> Result<IdCode>
pub fn add_var( &mut self, var_type: VarType, width: u32, reference: &str, index: Option<ReferenceIndex>, ) -> Result<IdCode>
Writes a $var command with the next available ID, returning the assigned ID.
Convenience wrapper around var_def.
Sourcepub fn add_wire(&mut self, width: u32, reference: &str) -> Result<IdCode>
pub fn add_wire(&mut self, width: u32, reference: &str) -> Result<IdCode>
Adds a $var for a wire with the next available ID, returning the assigned ID.
Convenience wrapper around add_var.
Sourcepub fn var(&mut self, v: &Var) -> Result<()>
pub fn var(&mut self, v: &Var) -> Result<()>
Writes a $var command from a Var structure from the parser.
Sourcepub fn enddefinitions(&mut self) -> Result<()>
pub fn enddefinitions(&mut self) -> Result<()>
Writes a $enddefinitions command to end the header.
Sourcepub fn change_scalar<V: Into<Value>>(&mut self, id: IdCode, v: V) -> Result<()>
pub fn change_scalar<V: Into<Value>>(&mut self, id: IdCode, v: V) -> Result<()>
Writes a change to a scalar variable.
Sourcepub fn change_vector(&mut self, id: IdCode, v: &VecValue) -> Result<()>
pub fn change_vector(&mut self, id: IdCode, v: &VecValue) -> Result<()>
Writes a change to a vector variable.
Sourcepub fn change_real(&mut self, id: IdCode, v: f64) -> Result<()>
pub fn change_real(&mut self, id: IdCode, v: f64) -> Result<()>
Writes a change to a real variable.
Sourcepub fn change_string(&mut self, id: IdCode, v: &str) -> Result<()>
pub fn change_string(&mut self, id: IdCode, v: &str) -> Result<()>
Writes a change to a string variable.
Sourcepub fn begin(&mut self, c: SimulationCommand) -> Result<()>
pub fn begin(&mut self, c: SimulationCommand) -> Result<()>
Writes the beginning of a simulation command.